using System.Windows.Forms;
using System.Resources;

string escCh = "@COMMA";
string resxPath = Path.Combine(Path.GetDirectoryName(ScriptFilePath), Application.Settings.LanguageCode == "ja" ? "Resources.ja.resx" : "Resources.resx");
ResXResourceSet resx = new ResXResourceSet(resxPath);

// 作図部品一覧で選択しているノード
var selectedItem = DrawComponentBar.SelectedItem;

// 作図部品一覧ウィンドウでアイテムが選択されていない場合
if(selectedItem == null)
{
  MessageBox.Show(resx.GetString("SelectItemMessage"));
  return;
}

// クリップボードから属性テキストを読み込む
string clipboadText = Clipboard.GetText();

// カンマ区切りの文字列リスト
var attList = clipboadText.Replace("\r\n","\n").Split(new[]{'\n','\r'});

// 属性ディクショナリ
var attributeDic = new Dictionary<string, string>();

// 属性ディクショナリに属性をセット
foreach(var att in attList)
{
  var attPair = att.Split(',');

  if(attPair.Length == 2)
  {
    if(attPair[0] != null)
      attributeDic.Add(attPair[0].Replace(escCh, ","), attPair[1].Replace(escCh, ","));
  }
}

// 貼り付ける属性がない場合
if(attributeDic.Count == 0)
{
  MessageBox.Show(resx.GetString("CopyFirstMessage"));
  return;
}

// 作図部品の属性を取得
var componentAtt = selectedItem.MasterDrawComponent.Attributes;

// 作図部品に属性をセット
foreach(KeyValuePair<string, string> kvp in attributeDic)
{
  // 属性を登録
  if(componentAtt[kvp.Key] == null)
    componentAtt.Add(kvp.Key, kvp.Value);
  // すでにある場合は属性値を上書き
  else
    componentAtt[kvp.Key].Value = kvp.Value;
}

// ステータスバーにインフォメーションを表示
StatusBar.SetInformation(resx.GetString("PastedMessage"), 3000);
